@@ -1,13 +1,13 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 
-var Widget = require('@phosphor/widgets').Widget;
+var Widget = require('@lumino/widgets').Widget;
 
 var factory = {
   safe: true,
   mimeTypes: ['text/plain'],
   defaultRank: 1000,
-  createRenderer: function() {
+  createRenderer: function () {
     return new Widget();
   }
 };
